@@ -9,17 +9,16 @@ g = Digraph('G', filename='cluster.gv')
 #       so that Graphviz recognizes it as a special cluster subgraph
 
 with g.subgraph(name='cluster_0') as c:
-    c.attr(style='filled')
-    c.attr(color='lightgrey')
+    c.attr(style='filled', color='lightgrey')
     c.node_attr.update(style='filled', color='white')
     c.edges([('a0', 'a1'), ('a1', 'a2'), ('a2', 'a3')])
     c.attr(label='process #1')
 
 with g.subgraph(name='cluster_1') as c:
-    c.node_attr.update(style='filled')
+    c.attr(color='blue')
+    c.node_attr['style'] = 'filled'
     c.edges([('b0', 'b1'), ('b1', 'b2'), ('b2', 'b3')])
     c.attr(label='process #2')
-    c.attr(color='blue')
 
 g.edge('start', 'a0')
 g.edge('start', 'b0')
